# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/000_vision.load.ipynb.

# %% ../../nbs/000_vision.load.ipynb 1
from __future__ import annotations

# %% auto 0
__all__ = ['MSTensorGetter']

# %% ../../nbs/000_vision.load.ipynb 3
from typing import Callable
from fastai.vision.all import *

# %% ../../nbs/000_vision.load.ipynb 5
class MSTensorGetter:
    pass

@patch
def load_tensor(self: MSTensorGetter, band_ids: list[str], img_id: Any) -> TensorImageMS:
    pass

# %% ../../nbs/000_vision.load.ipynb 7
class _MSFileTensorGetter(MSTensorGetter):
    pass

@patch
def __init__(
    self: _MSFileTensorGetter,
    files_getter: Callable[[list[str], Any], list[str]],
    chan_io_fn: Callable[[list[str]], TensorImageMS]
):
    store_attr()

@patch
def load_tensor(self: _MSFileTensorGetter, band_ids: list[str], img_id: Any) -> TensorImageMS:
    files = self.files_getter(band_ids, img_id)
    return self.chan_io_fn(files)

# %% ../../nbs/000_vision.load.ipynb 9
class _MSDelegatingTensorGetter(MSTensorGetter):
    pass

@patch
def __init__(
    self: _MSDelegatingTensorGetter,
    tg_fn: Callable[[list[str], Any], TensorImageMS]
):
    store_attr()

@patch
def load_tensor(self: _MSDelegatingTensorGetter, band_ids: list[str], img_id: Any) -> TensorImageMS:
    return self.tg_fn(band_ids, img_id)

# %% ../../nbs/000_vision.load.ipynb 11
@patch(cls_method=True)
def from_files(
    cls: MSTensorGetter,
    files_getter: Callable[[list[str], Any], list[str]],
    chan_io_fn: Callable[[list[str]], TensorImageMS]
):
    return _MSFileTensorGetter(files_getter, chan_io_fn)

@patch(cls_method=True)
def from_delegate(
    cls: MSTensorGetter,
    tg_fn: Callable[[list[str], Any], TensorImageMS]
):
    return _MSDelegatingTensorGetter(tg_fn)



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/fastgs',
                'doc_host': 'https://restlessronin.github.io',
                'git_url': 'https://github.com/restlessronin/fastgs',
                'lib_path': 'fastgs'},
  'syms': { 'fastgs.multispectral': { 'fastgs.multispectral.BandInputs': ('multispectral.html#bandinputs', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs._get_bands': ( 'multispectral.html#bandinputs._get_bands',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs._get_index': ( 'multispectral.html#bandinputs._get_index',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs.from_ids': ( 'multispectral.html#bandinputs.from_ids',
                                                                                    'fastgs/multispectral.py'),
                                      'fastgs.multispectral.BandInputs.get_bands_list': ( 'multispectral.html#bandinputs.get_bands_list',
                                                                                          'fastgs/multispectral.py'),
                                      'fastgs.multispectral.FastGS': ('multispectral.html#fastgs', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.FastGS.__init__': ( 'multispectral.html#fastgs.__init__',
                                                                                'fastgs/multispectral.py'),
                                      'fastgs.multispectral.FastGS.create_data_block': ( 'multispectral.html#fastgs.create_data_block',
                                                                                         'fastgs/multispectral.py'),
                                      'fastgs.multispectral.FastGS.create_unet_learner': ( 'multispectral.html#fastgs.create_unet_learner',
                                                                                           'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSAugment': ('multispectral.html#msaugment', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSAugment.__init__': ( 'multispectral.html#msaugment.__init__',
                                                                                   'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSAugment.create_item_xforms': ( 'multispectral.html#msaugment.create_item_xforms',
                                                                                             'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData': ('multispectral.html#msdata', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.__init__': ( 'multispectral.html#msdata.__init__',
                                                                                'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData._load_image': ( 'multispectral.html#msdata._load_image',
                                                                                   'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.create_xform_block': ( 'multispectral.html#msdata.create_xform_block',
                                                                                          'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.from_all': ( 'multispectral.html#msdata.from_all',
                                                                                'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.from_delegate': ( 'multispectral.html#msdata.from_delegate',
                                                                                     'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.load_image': ( 'multispectral.html#msdata.load_image',
                                                                                  'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSData.num_channels': ( 'multispectral.html#msdata.num_channels',
                                                                                    'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor': ('multispectral.html#msdescriptor', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.__init__': ( 'multispectral.html#msdescriptor.__init__',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.from_all': ( 'multispectral.html#msdescriptor.from_all',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.from_band_brgt': ( 'multispectral.html#msdescriptor.from_band_brgt',
                                                                                            'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.from_bands': ( 'multispectral.html#msdescriptor.from_bands',
                                                                                        'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.get_brgtX': ( 'multispectral.html#msdescriptor.get_brgtx',
                                                                                       'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.get_brgtX_list': ( 'multispectral.html#msdescriptor.get_brgtx_list',
                                                                                            'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MSDescriptor.get_res_ids': ( 'multispectral.html#msdescriptor.get_res_ids',
                                                                                         'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData': ('multispectral.html#maskdata', 'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.__init__': ( 'multispectral.html#maskdata.__init__',
                                                                                  'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.create_xform_block': ( 'multispectral.html#maskdata.create_xform_block',
                                                                                            'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.load_mask': ( 'multispectral.html#maskdata.load_mask',
                                                                                   'fastgs/multispectral.py'),
                                      'fastgs.multispectral.MaskData.num_channels': ( 'multispectral.html#maskdata.num_channels',
                                                                                      'fastgs/multispectral.py'),
                                      'fastgs.multispectral.createSentinel2Descriptor': ( 'multispectral.html#createsentinel2descriptor',
                                                                                          'fastgs/multispectral.py')},
            'fastgs.test.fixture': { 'fastgs.test.fixture._get_11b_data_block': ( 'test.fixture.html#_get_11b_data_block',
                                                                                  'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture._get_11b_msdata': ('test.fixture.html#_get_11b_msdata', 'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture._get_augs': ('test.fixture.html#_get_augs', 'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture._get_mask_data': ('test.fixture.html#_get_mask_data', 'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture.get_11b_test_dl': ('test.fixture.html#get_11b_test_dl', 'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture.get_11b_test_fgs': ( 'test.fixture.html#get_11b_test_fgs',
                                                                               'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture.get_11b_test_learner': ( 'test.fixture.html#get_11b_test_learner',
                                                                                   'fastgs/test/fixture.py'),
                                     'fastgs.test.fixture.get_11b_test_tuple': ( 'test.fixture.html#get_11b_test_tuple',
                                                                                 'fastgs/test/fixture.py')},
            'fastgs.test.io': { 'fastgs.test.io._filter_masked': ('test.io.html#_filter_masked', 'fastgs/test/io.py'),
                                'fastgs.test.io._get_input': ('test.io.html#_get_input', 'fastgs/test/io.py'),
                                'fastgs.test.io._tile_img_name': ('test.io.html#_tile_img_name', 'fastgs/test/io.py'),
                                'fastgs.test.io._to_bin_seg': ('test.io.html#_to_bin_seg', 'fastgs/test/io.py'),
                                'fastgs.test.io.get_channel_filenames': ('test.io.html#get_channel_filenames', 'fastgs/test/io.py'),
                                'fastgs.test.io.read_chn_file': ('test.io.html#read_chn_file', 'fastgs/test/io.py'),
                                'fastgs.test.io.read_mask_file': ('test.io.html#read_mask_file', 'fastgs/test/io.py'),
                                'fastgs.test.io.read_multichan_files': ('test.io.html#read_multichan_files', 'fastgs/test/io.py')},
            'fastgs.vision.augment': { 'fastgs.vision.augment._create_ms_seg_alb_xfm_cls': ( 'vision.augment.html#_create_ms_seg_alb_xfm_cls',
                                                                                             'fastgs/vision/augment.py'),
                                       'fastgs.vision.augment._ms_seg_alb_xfm_encodes': ( 'vision.augment.html#_ms_seg_alb_xfm_encodes',
                                                                                          'fastgs/vision/augment.py'),
                                       'fastgs.vision.augment._ms_seg_alb_xfm_init': ( 'vision.augment.html#_ms_seg_alb_xfm_init',
                                                                                       'fastgs/vision/augment.py')},
            'fastgs.vision.core': { 'fastgs.vision.core.TensorImageMS': ('vision.core.html#tensorimagems', 'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._brighten': ( 'vision.core.html#tensorimagems._brighten',
                                                                                    'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._get_grid': ( 'vision.core.html#tensorimagems._get_grid',
                                                                                    'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._select_bands': ( 'vision.core.html#tensorimagems._select_bands',
                                                                                        'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._show_animation': ( 'vision.core.html#tensorimagems._show_animation',
                                                                                          'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._show_tiles': ( 'vision.core.html#tensorimagems._show_tiles',
                                                                                      'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.from_tensor': ( 'vision.core.html#tensorimagems.from_tensor',
                                                                                      'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.from_tensor_bands': ( 'vision.core.html#tensorimagems.from_tensor_bands',
                                                                                            'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.num_images': ( 'vision.core.html#tensorimagems.num_images',
                                                                                     'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.show': ( 'vision.core.html#tensorimagems.show',
                                                                               'fastgs/vision/core.py')},
            'fastgs.vision.data': { 'fastgs.vision.data._get_sample_ctxs': ('vision.data.html#_get_sample_ctxs', 'fastgs/vision/data.py'),
                                    'fastgs.vision.data._show_one_sample': ('vision.data.html#_show_one_sample', 'fastgs/vision/data.py'),
                                    'fastgs.vision.data.show_batch': ('vision.data.html#show_batch', 'fastgs/vision/data.py')},
            'fastgs.vision.learner': { 'fastgs.vision.learner._get_sample_ctxs': ( 'vision.learner.html#_get_sample_ctxs',
                                                                                   'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner._show_one_result': ( 'vision.learner.html#_show_one_result',
                                                                                   'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner.nn.Conv2d.fastgs_reinit_weights': ( 'vision.learner.html#nn.conv2d.fastgs_reinit_weights',
                                                                                                  'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner.plot_top_losses': ( 'vision.learner.html#plot_top_losses',
                                                                                  'fastgs/vision/learner.py'),
                                       'fastgs.vision.learner.show_results': ( 'vision.learner.html#show_results',
                                                                               'fastgs/vision/learner.py')},
            'fastgs.vision.load': { 'fastgs.vision.load.MSTensorGetter': ('vision.load.html#mstensorgetter', 'fastgs/vision/load.py'),
                                    'fastgs.vision.load.MSTensorGetter.from_delegate': ( 'vision.load.html#mstensorgetter.from_delegate',
                                                                                         'fastgs/vision/load.py'),
                                    'fastgs.vision.load.MSTensorGetter.from_files': ( 'vision.load.html#mstensorgetter.from_files',
                                                                                      'fastgs/vision/load.py'),
                                    'fastgs.vision.load.MSTensorGetter.load_tensor': ( 'vision.load.html#mstensorgetter.load_tensor',
                                                                                       'fastgs/vision/load.py'),
                                    'fastgs.vision.load._MSDelegatingTensorGetter': ( 'vision.load.html#_msdelegatingtensorgetter',
                                                                                      'fastgs/vision/load.py'),
                                    'fastgs.vision.load._MSDelegatingTensorGetter.__init__': ( 'vision.load.html#_msdelegatingtensorgetter.__init__',
                                                                                               'fastgs/vision/load.py'),
                                    'fastgs.vision.load._MSDelegatingTensorGetter.load_tensor': ( 'vision.load.html#_msdelegatingtensorgetter.load_tensor',
                                                                                                  'fastgs/vision/load.py'),
                                    'fastgs.vision.load._MSFileTensorGetter': ( 'vision.load.html#_msfiletensorgetter',
                                                                                'fastgs/vision/load.py'),
                                    'fastgs.vision.load._MSFileTensorGetter.__init__': ( 'vision.load.html#_msfiletensorgetter.__init__',
                                                                                         'fastgs/vision/load.py'),
                                    'fastgs.vision.load._MSFileTensorGetter.load_tensor': ( 'vision.load.html#_msfiletensorgetter.load_tensor',
                                                                                            'fastgs/vision/load.py')}}}
